@@ -2,12 +2,12 @@
  *	This is my wrapper-class to create
  *	a MD5 Hash from a string and a file.
  *
- *	This code is completly free, you 
- *	can copy it, modify it, or do 
+ *	This code is completly free, you
+ *	can copy it, modify it, or do
  *	what ever you want with it.
  *
  *	Feb. 2005
- *	Benjamin Grdelbach
+ *	Benjamin Grudelbach
  */
 
 //include protection
@@ -27,11 +27,11 @@ class md5wrapper
 {
 	private:
 		MD5 *md5;
-	
+
 		/*
 		 * internal hash function, calling
 		 * the basic methods from md5.h
-		 */	
+		 */
 		std::string hashit(std::string text);
 
 		/*
@@ -45,20 +45,20 @@ class md5wrapper
 
 		//destructor
 		~md5wrapper();
-		
+
 		/*
 		 * creates a MD5 hash from
 		 * "text" and returns it as
 		 * string
-		 */	
+		 */
 		std::string getHashFromString(std::string text);
 
 		/*
 		 * creates a MD5 hash from
-		 * a file specified in "filename" and 
+		 * a file specified in "filename" and
 		 * returns it as string
-		 */	
- 
+		 */
+
 };
 
 
